==> apigatewaylambda-2.6.0-sources.jar: software/amazon/awsconstructs/services/apigatewaylambda/ApiGatewayToLambda.java <==
package software.amazon.awsconstructs.services.apigatewaylambda;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.58.0 (build f8ba112)", date = "2022-05-07T18:41:36.107Z")
@software.amazon.jsii.Jsii(module = software.amazon.awsconstructs.services.apigatewaylambda.$Module.class, fqn = "@aws-solutions-constructs/aws-apigateway-lambda.ApiGatewayToLambda")
public class ApiGatewayToLambda extends software.constructs.Construct {

    protected ApiGatewayToLambda(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected ApiGatewayToLambda(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope - represents the scope for all the resources. This parameter is required.
     * @param id - this is a a scope-unique id. This parameter is required.
     * @param props - user provided props for the construct. This parameter is required.
     */
    public ApiGatewayToLambda(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awsconstructs.services.apigatewaylambda.ApiGatewayToLambdaProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.apigateway.RestApi getApiGateway() {
        return software.amazon.jsii.Kernel.get(this, "apiGateway", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.apigateway.RestApi.class));
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.logs.LogGroup getApiGatewayLogGroup() {
        return software.amazon.jsii.Kernel.get(this, "apiGatewayLogGroup", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.logs.LogGroup.class));
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.lambda.Function getLambdaFunction() {
        return software.amazon.jsii.Kernel.get(this, "lambdaFunction", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.lambda.Function.class));
    }

    public @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.iam.Role getApiGatewayCloudWatchRole() {
        return software.amazon.jsii.Kernel.get(this, "apiGatewayCloudWatchRole", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.iam.Role.class));
    }

    /**
     * A fluent builder for {@link software.amazon.awsconstructs.services.apigatewaylambda.ApiGatewayToLambda}.
     */
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awsconstructs.services.apigatewaylambda.ApiGatewayToLambda> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope - represents the scope for all the resources. This parameter is required.
         * @param id - this is a a scope-unique id. This parameter is required.
         */
        public static Builder create(final software.constructs.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.constructs.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awsconstructs.services.apigatewaylambda.ApiGatewayToLambdaProps.Builder props;

        private Builder(final software.constructs.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awsconstructs.services.apigatewaylambda.ApiGatewayToLambdaProps.Builder();
        }

        /**
         * Optional user-provided props to override the default props for the API.
         * <p>
         * Default: - Default props are used.
         * <p>
         * @return {@code this}
         * @param apiGatewayProps Optional user-provided props to override the default props for the API. This parameter is required.
         */
        public Builder apiGatewayProps(final java.lang.Object apiGatewayProps) {
            this.props.apiGatewayProps(apiGatewayProps);
            return this;
        }

        /**
         * Existing instance of Lambda Function object, providing both this and `lambdaFunctionProps` will cause an error.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param existingLambdaObj Existing instance of Lambda Function object, providing both this and `lambdaFunctionProps` will cause an error. This parameter is required.
         */
        public Builder existingLambdaObj(final software.amazon.awscdk.services.lambda.Function existingLambdaObj) {
            this.props.existingLambdaObj(existingLambdaObj);
            return this;
        }

        /**
         * User provided props to override the default props for the Lambda function.
         * <p>
         * Default: - Default props are used.
         * <p>
         * @return {@code this}
         * @param lambdaFunctionProps User provided props to override the default props for the Lambda function. This parameter is required.
         */
        public Builder lambdaFunctionProps(final software.amazon.awscdk.services.lambda.FunctionProps lambdaFunctionProps) {
            this.props.lambdaFunctionProps(lambdaFunctionProps);
            return this;
        }

        /**
         * User provided props to override the default props for the CloudWatchLogs LogGroup.
         * <p>
         * Default: - Default props are used
         * <p>
         * @return {@code this}
         * @param logGroupProps User provided props to override the default props for the CloudWatchLogs LogGroup. This parameter is required.
         */
        public Builder logGroupProps(final software.amazon.awscdk.services.logs.LogGroupProps logGroupProps) {
            this.props.logGroupProps(logGroupProps);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awsconstructs.services.apigatewaylambda.ApiGatewayToLambda}.
         */
        @Override
        public software.amazon.awsconstructs.services.apigatewaylambda.ApiGatewayToLambda build() {
            return new software.amazon.awsconstructs.services.apigatewaylambda.ApiGatewayToLambda(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}

==> apigatewaylambda-2.59.0-sources.jar: software/amazon/awsconstructs/services/apigatewaylambda/ApiGatewayToLambda.java <==
package software.amazon.awsconstructs.services.apigatewaylambda;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.99.0 (build 8f757e4)", date = "2024-06-08T13:26:38.129Z")
@software.amazon.jsii.Jsii(module = software.amazon.awsconstructs.services.apigatewaylambda.$Module.class, fqn = "@aws-solutions-constructs/aws-apigateway-lambda.ApiGatewayToLambda")
public class ApiGatewayToLambda extends software.constructs.Construct {

    protected ApiGatewayToLambda(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected ApiGatewayToLambda(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope <ul><li>represents the scope for all the resources.</li></ul> This parameter is required.
     * @param id <ul><li>this is a a scope-unique id.</li></ul> This parameter is required.
     * @param props <ul><li>user provided props for the construct.</li></ul> This parameter is required.
     */
    public ApiGatewayToLambda(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awsconstructs.services.apigatewaylambda.ApiGatewayToLambdaProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.apigateway.RestApi getApiGateway() {
        return software.amazon.jsii.Kernel.get(this, "apiGateway", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.apigateway.RestApi.class));
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.logs.LogGroup getApiGatewayLogGroup() {
        return software.amazon.jsii.Kernel.get(this, "apiGatewayLogGroup", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.logs.LogGroup.class));
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.lambda.Function getLambdaFunction() {
        return software.amazon.jsii.Kernel.get(this, "lambdaFunction", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.lambda.Function.class));
    }

    public @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.iam.Role getApiGatewayCloudWatchRole() {
        return software.amazon.jsii.Kernel.get(this, "apiGatewayCloudWatchRole", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.iam.Role.class));
    }

    /**
     * A fluent builder for {@link software.amazon.awsconstructs.services.apigatewaylambda.ApiGatewayToLambda}.
     */
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awsconstructs.services.apigatewaylambda.ApiGatewayToLambda> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope <ul><li>represents the scope for all the resources.</li></ul> This parameter is required.
         * @param id <ul><li>this is a a scope-unique id.</li></ul> This parameter is required.
         */
        public static Builder create(final software.constructs.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.constructs.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awsconstructs.services.apigatewaylambda.ApiGatewayToLambdaProps.Builder props;

        private Builder(final software.constructs.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awsconstructs.services.apigatewaylambda.ApiGatewayToLambdaProps.Builder();
        }

        /**
         * Optional user-provided props to override the default props for the API.
         * <p>
         * Default: - Default props are used.
         * <p>
         * @return {@code this}
         * @param apiGatewayProps Optional user-provided props to override the default props for the API. This parameter is required.
         */
        public Builder apiGatewayProps(final java.lang.Object apiGatewayProps) {
            this.props.apiGatewayProps(apiGatewayProps);
            return this;
        }

        /**
         * Existing instance of Lambda Function object, providing both this and <code>lambdaFunctionProps</code> will cause an error.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param existingLambdaObj Existing instance of Lambda Function object, providing both this and <code>lambdaFunctionProps</code> will cause an error. This parameter is required.
         */
        public Builder existingLambdaObj(final software.amazon.awscdk.services.lambda.Function existingLambdaObj) {
            this.props.existingLambdaObj(existingLambdaObj);
            return this;
        }

        /**
         * User provided props to override the default props for the Lambda function.
         * <p>
         * Default: - Default props are used.
         * <p>
         * @return {@code this}
         * @param lambdaFunctionProps User provided props to override the default props for the Lambda function. This parameter is required.
         */
        public Builder lambdaFunctionProps(final software.amazon.awscdk.services.lambda.FunctionProps lambdaFunctionProps) {
            this.props.lambdaFunctionProps(lambdaFunctionProps);
            return this;
        }

        /**
         * User provided props to override the default props for the CloudWatchLogs LogGroup.
         * <p>
         * Default: - Default props are used
         * <p>
         * @return {@code this}
         * @param logGroupProps User provided props to override the default props for the CloudWatchLogs LogGroup. This parameter is required.
         */
        public Builder logGroupProps(final software.amazon.awscdk.services.logs.LogGroupProps logGroupProps) {
            this.props.logGroupProps(logGroupProps);
            return this;
        }

        /**
         * @return a newly built instance of {@link software.amazon.awsconstructs.services.apigatewaylambda.ApiGatewayToLambda}.
         */
        @Override
        public software.amazon.awsconstructs.services.apigatewaylambda.ApiGatewayToLambda build() {
            return new software.amazon.awsconstructs.services.apigatewaylambda.ApiGatewayToLambda(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}
